module.exports = defineTest({
	description: 'use strict should not be present',
	options: {
		output: {
			strict: false
		}
	}
});
